' ****************************************************************************************
' HTMLDocumentEvents2 dispatch interface
' This dispinterface provides a connection point so that an application or control can
' intercept events fired by a document object.
' IID = {3050F613-98B5-11CF-BB82-00AA00BDCE0B}
' Attributes = 4112 [&H1010]  [Hidden] [Dispatchable]
' Number of functions = 38
' ****************************************************************************************

' ****************************************************************************************
' EXCEPINFO structure
' ****************************************************************************************
Type HTMLDocumentEvents2_EXCEPINFO
   wCode As Word               ' An error code describing the error.
   wReserved As Word           ' Reserved
   bstrSource As Dword         ' Source of the exception.
   bstrDescription As Dword    ' Textual description of the error.
   bstrHelpFile As Dword       ' Help file path.
   dwHelpContext As Dword      ' Help context ID.
   pvReserved As Dword         ' Reserved.
   pfnDeferredFillIn As Dword  ' Pointer to function that fills in Help and description info.
   scode As Dword              ' An error code describing the error.
End Type
' ****************************************************************************************

' ****************************************************************************************
' Returns a pointer to a specified interface on an object to which a client currently holds an
' interface pointer.
' ****************************************************************************************
Function HTMLDocumentEvents2_IUnknown_QueryInterface (ByVal pthis As Dword Ptr, ByRef riid As Guid, ByRef ppvObj As Dword) As Long
   Local HRESULT As Long
   Call Dword @@pthis[0] Using HTMLDocumentEvents2_IUnknown_QueryInterface(pthis, riid, ppvObj) To HRESULT
   Function = HRESULT
End Function
' ****************************************************************************************

' ****************************************************************************************
' Decrements the reference count for the calling interface on a object. If the reference count
' on the object falls to 0, the object is freed from memory.
' ****************************************************************************************
Function HTMLDocumentEvents2_IUnknown_Release (ByVal pthis As Dword Ptr) As Dword
   Local DWRESULT As Dword
   Call Dword @@pthis[2] Using HTMLDocumentEvents2_IUnknown_Release(pthis) To DWRESULT
   Function = DWRESULT
End Function
' ****************************************************************************************

' ****************************************************************************************
' IConnectionPointContainer::FindConnectionPoint
' Returns a pointer to the IConnectionPoint interface of a connection point for a specified IID,
' if that IID describes a supported outgoing interface.
' ****************************************************************************************
Function HTMLDocumentEvents2_IConnectionPointContainer_FindConnectionPoint (ByVal pthis As Dword Ptr, ByRef riid As Guid, ByRef ppCP As Dword) As Long
   Local HRESULT As Long
   Call Dword @@pthis[4] Using HTMLDocumentEvents2_IConnectionPointContainer_FindConnectionPoint(pthis, riid, ppCP) To HRESULT
   Function = HRESULT
End Function
' ****************************************************************************************

' ****************************************************************************************
' IConnectionPoint::Advise
' Establishes a connection between the connection point object and the client's sink.
' ****************************************************************************************
Function HTMLDocumentEvents2_IConnectionPoint_Advise (ByVal pthis As Dword Ptr, _
   ByVal pUnkSink As Dword, ByRef pdwCookie As Dword) As Long
   Local HRESULT As Long
   Call Dword @@pthis[5] Using HTMLDocumentEvents2_IConnectionPoint_Advise(pthis, pUnkSink, pdwCookie) To HRESULT
   Function = HRESULT
End Function
' ****************************************************************************************

' ****************************************************************************************
' IConnectionPoint::Unadvise
' Terminates an advisory connection previously established through IConnectionPoint_Advise.
' The dwCookie parameter identifies the connection to terminate.
' ****************************************************************************************
Function HTMLDocumentEvents2_IConnectionPoint_Unadvise (ByVal pthis As Dword Ptr, ByVal dwCookie As Dword) As Long
   Local HRESULT As Long
   Call Dword @@pthis[6] Using HTMLDocumentEvents2_IConnectionPoint_Unadvise(pthis, dwCookie) To HRESULT
   Function = HRESULT
End Function
' ****************************************************************************************

' ****************************************************************************************
' IDispatch virtual table
' ****************************************************************************************
Type HTMLDocumentEvents2_IDispatchVtbl
   QueryInterface As Dword     ' Returns pointers to supported interfaces
   AddRef As Dword             ' Increments reference count
   Release As Dword            ' Decrements reference count
   GetTypeInfoCount As Dword   ' Retrieves the number of type descriptions
   GetTypeInfo As Dword        ' Retrieves a description of object's programmable interface
   GetIDsOfNames As Dword      ' Maps name of method or property to DispId
   Invoke As Dword             ' Calls one of the object's methods, or gets/sets one of its properties
   pVtblAddr As Dword          ' Address of the virtual table
   cRef As Dword               ' Reference counter
   pthis As Dword              ' IUnknown or IDispatch of the control that fires the events
End Type
' ****************************************************************************************

' ****************************************************************************************
' UI4 AddRef()
' Increments the reference counter.
' ****************************************************************************************
Function HTMLDocumentEvents2_AddRef (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr) As Dword
   Incr @@pCookie.cRef
   Function = @@pCookie.cRef
End Function
' ****************************************************************************************

' ****************************************************************************************
' HRESULT QueryInterface([in] *GUID riid, [out] **VOID ppvObj)
' Returns the IUnknown of our class and increments the reference counter.
' ****************************************************************************************
Function HTMLDocumentEvents2_QueryInterface (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, _
   ByRef riid As Guid, ByRef ppvObj As Dword) As Long
   ppvObj = pCookie
   HTMLDocumentEvents2_AddRef pCookie
   Function = %S_OK
End Function
' ****************************************************************************************

' ****************************************************************************************
' UI4 Release()
' Releases our class if there is only a reference to him and decrements the reference counter.
' ****************************************************************************************
Function HTMLDocumentEvents2_Release (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr) As Dword
   Local pVtblAddr As Dword
   If @@pCookie.cRef = 1 Then
      pVtblAddr = @@pCookie.pVtblAddr
      If IsFalse HeapFree(GetProcessHeap(), 0, ByVal pVtblAddr) Then
         Function = @@pCookie.cRef
         Exit Function
      End If
   End If
   Decr @@pCookie.cRef
   Function = @@pCookie.cRef
End Function
' ****************************************************************************************

' ****************************************************************************************
' HRESULT GetTypeInfoCount([out] *UINT pctinfo)
' ****************************************************************************************
Function HTMLDocumentEvents2_GetTypeInfoCount (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pctInfo As Dword) As Long
   Function = %E_NOTIMPL
End Function
' ****************************************************************************************

' ****************************************************************************************
' HRESULT GetTypeInfo([in] UINT itinfo, [in] UI4 lcid, [out] **VOID pptinfo)
' ****************************************************************************************
Function HTMLDocumentEvents2_GetTypeInfo (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, _
   ByVal itinfo As Dword, ByVal lcid As Dword, ByRef pptinfo As Dword) As Long
   Function = %E_NOTIMPL
End Function
' ****************************************************************************************

' ****************************************************************************************
' HRESULT GetIDsOfNames([in] *GUID riid, [in] **I1 rgszNames, [in] UINT cNames, [in] UI4 lcid, [out] *I4 rgdispid)
' ****************************************************************************************
Function HTMLDocumentEvents2_GetIDsOfNames ( ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, _
   ByRef riid As Guid, ByVal rgszNames As Dword, ByVal cNames As Dword, ByVal lcid As Dword, ByRef rgdispid As Long) As Long
   Function = %E_NOTIMPL
End Function
' ****************************************************************************************

' ****************************************************************************************
' Builds the IDispatch Virtual Table
' ****************************************************************************************
Function HTMLDocumentEvents2_BuildVtbl (ByVal pthis As Dword) As Dword

   Local pVtbl As HTMLDocumentEvents2_IDispatchVtbl Ptr
   Local pUnk As HTMLDocumentEvents2_IDispatchVtbl Ptr

   pVtbl = HeapAlloc(GetProcessHeap(), %HEAP_ZERO_MEMORY, SizeOf(@pVtbl))
   If pVtbl = 0 Then Exit Function

   @pVtbl.QueryInterface   = CodePtr(HTMLDocumentEvents2_QueryInterface)
   @pVtbl.AddRef           = CodePtr(HTMLDocumentEvents2_AddRef)
   @pVtbl.Release          = CodePtr(HTMLDocumentEvents2_Release)
   @pVtbl.GetTypeInfoCount = CodePtr(HTMLDocumentEvents2_GetTypeInfoCount)
   @pVtbl.GetTypeInfo      = CodePtr(HTMLDocumentEvents2_GetTypeInfo)
   @pVtbl.GetIDsOfNames    = CodePtr(HTMLDocumentEvents2_GetIDsOfNames)
   @pVtbl.Invoke           = CodePtr(HTMLDocumentEvents2_Invoke)
   @pVtbl.pVtblAddr        = pVtbl
   @pVtbl.pthis            = pthis

   pUnk = VarPtr(@pVtbl.pVtblAddr)
   Function = pUnk

End Function
' ****************************************************************************************

' ****************************************************************************************
' Establishes a connection between the connection point object and the client's sink.
' Returns a token that uniquely identifies this connection.
' ****************************************************************************************
Function HTMLDocumentEvents2_ConnectEvents (ByVal pthis As Dword, ByRef pdwCookie As Dword) As Long

   Local HRESULT As Long                 ' HRESULT code
   Local pCPC As Dword                   ' IConnectionPointContainer
   Local pCP As Dword                    ' IConnectionPoint
   Local IID_CPC As Guid                 ' IID_IConnectionPointContainer
   Local IID_CP As Guid                  ' Events dispinterface
   Local dwCookie As Dword               ' Returned token
   Local pUnkSink As Dword               ' IUnknown of the class

   IID_CPC = Guid$("{B196B284-BAB4-101A-B69C-00AA00341D07}")
   IID_CP  = Guid$("{3050F613-98B5-11CF-BB82-00AA00BDCE0B}")

   If pthis = 0 Then Function = -1 : Exit Function
   HRESULT = HTMLDocumentEvents2_IUnknown_QueryInterface(pthis, IID_CPC, pCPC)
   If HRESULT <> %S_OK Then Function = HRESULT : Exit Function

   HRESULT = HTMLDocumentEvents2_IConnectionPointContainer_FindConnectionPoint(pCPC, IID_CP, pCP)
   HTMLDocumentEvents2_IUnknown_Release pCPC
   If HRESULT <> %S_OK Then Function = HRESULT : Exit Function

   pUnkSink = HTMLDocumentEvents2_BuildVtbl(pthis)
   If IsTrue pUnkSink Then HRESULT = HTMLDocumentEvents2_IConnectionPoint_Advise(pCP, pUnkSink, dwCookie)
   HTMLDocumentEvents2_IUnknown_Release pCP
   pdwCookie = dwCookie
   Function = HRESULT

End Function
' ****************************************************************************************

' ****************************************************************************************
' Releases the events connection identified with the cookie returned by the ConnectEvents function
' ****************************************************************************************
Function HTMLDocumentEvents2_DisconnectEvents (ByVal pthis As Dword, ByVal dwCookie As Dword) As Long

   Local HRESULT As Long                 ' HRESULT code
   Local pCPC As Dword                   ' IConnectionPointContainer
   Local pCP As Dword                    ' IConnectionPoint
   Local IID_CPC As Guid                 ' IID_IConnectionPointContainer
   Local IID_CP As Guid                  ' ConnectionEvents dispinterface

   IID_CPC = Guid$("{B196B284-BAB4-101A-B69C-00AA00341D07}")
   IID_CP  = Guid$("{3050F613-98B5-11CF-BB82-00AA00BDCE0B}")

   If pthis = 0 Then Function = -1 : Exit Function
   HRESULT = HTMLDocumentEvents2_IUnknown_QueryInterface(pthis, IID_CPC, pCPC)
   If HRESULT <> %S_OK Then Function = HRESULT : Exit Function

   HRESULT = HTMLDocumentEvents2_IConnectionPointContainer_FindConnectionPoint(pCPC, IID_CP, pCP)
   HTMLDocumentEvents2_IUnknown_Release pCPC
   If HRESULT <> %S_OK Then Function = HRESULT : Exit Function

   HRESULT = HTMLDocumentEvents2_IConnectionPoint_Unadvise(pCP, dwCookie)
   HTMLDocumentEvents2_IUnknown_Release pCP
   Function = HRESULT

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onhelp
' Fires when the user presses the F1 key while the browser is the active window.
' Member identifier: &H8001000A (-2147418102)
' ****************************************************************************************
Function HTMLDocumentEvents2_onhelp (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onclick
' Fires when the user clicks the left mouse button on the object.
' Member identifier: &HFFFFFDA8 (-600)
' ****************************************************************************************
Function HTMLDocumentEvents2_onclick (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

   Local ppElement As Dword             ' // Element that has fired the event
   Local strId As String                ' // Identifier of the element that has fired the event
   Local strValue As String             ' // Value of the property

   ' // Get a reference to the element that has fired the event
   If pEvtObj Then ppElement = IHTMLEventObj_get_srcElement(pEvtObj)
   If ppElement Then
      ' // Get the identifier of the element that has fired the event
      strId = IHTMLElement_get_id(ppElement)
      Select Case strId
         Case "Button_1", "Button_2", "Button_3", "Button_4"
            HTMLDocument_SetElementInnerHtmlById pthis, "output", "You have clicked " & strId
         Case "Button_GetText"
            strValue = HTMLDocument_GetElementValueById(pthis, "Input_Text")
            MsgBox strValue
      End Select
      ' // Release the IHTMLElement interface
      HTMLDocumentEvents2_IUnknown_Release ppElement
   End If

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: ondblclick
' Fires when the user double-clicks the object.
' Member identifier: &HFFFFFDA7 (-601)
' ****************************************************************************************
Function HTMLDocumentEvents2_ondblclick (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onkeydown
' Fires when the user presses a key.
' Member identifier: &HFFFFFDA6 (-602)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onkeydown (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onkeyup
' Fires when the user releases a key.
' Member identifier: &HFFFFFDA4 (-604)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onkeyup (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onkeypress
' Fires when the user presses an alphanumeric key.
' Member identifier: &HFFFFFDA5 (-603)
' ****************************************************************************************
Function HTMLDocumentEvents2_onkeypress (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onmousedown
' Fires when the user clicks the object with either mouse button.
' Member identifier: &HFFFFFDA3 (-605)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onmousedown (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onmousemove
' Fires when the user moves the mouse over the object.
' Member identifier: &HFFFFFDA2 (-606)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onmousemove (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onmouseup
' ires when the user releases a mouse button while the mouse is over the object.
' Member identifier: &HFFFFFDA1 (-607)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onmouseup (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onmouseout
' Fires when the user moves the mouse pointer outside the boundaries of the object.
' Member identifier: &H80010009 (-2147418103)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onmouseout (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onmouseover
' Fires when the user moves the mouse pointer into the object.
' Member identifier: &H80010008 (-2147418104)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onmouseover (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onreadystatechange
' Fires when the state of the object has changed.
' Member identifier: &HFFFFFD9F (-609)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onreadystatechange (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onbeforeupdate
' Fires on a databound object before updating the associated data in the data source object.
' Member identifier: &H80010004 (-2147418108)
' ****************************************************************************************
Function HTMLDocumentEvents2_onbeforeupdate (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onafterupdate
' Fires on a databound object after successfully updating the associated data in the data
' source object.
' Member identifier: &H80010005 (-2147418107)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onafterupdate (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onrowexit
' Fires just before the data source control changes the current row in the object.
' Member identifier: &H80010006 (-2147418106)
' ****************************************************************************************
Function HTMLDocumentEvents2_onrowexit (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onrowenter
' Fires to indicate that the current row has changed in the data source and new data
' values are available on the object.
' Member identifier: &H80010007 (-2147418105)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onrowenter (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: ondragstart
' Fires on the source object when the user starts to drag a text selection or selected object.
' Member identifier: &H8001000B (-2147418101)
' ****************************************************************************************
Function HTMLDocumentEvents2_ondragstart (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onselectstart
' Fires when the object is being selected.
' Member identifier: &H8001000C (-2147418100)
' ****************************************************************************************
Function HTMLDocumentEvents2_onselectstart (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onerrorupdate
' Fires on a databound object when an error occurs while updating the associated data in
' the data source object.
' Member identifier: &H8001000D (-2147418099)
' ****************************************************************************************
Function HTMLDocumentEvents2_onerrorupdate (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: oncontextmenu
' Fires when the user clicks the right mouse button in the client area, opening the
' context menu.
' Member identifier: &H000003FF (1023)
' ****************************************************************************************
Function HTMLDocumentEvents2_oncontextmenu (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onstop
' Fires when the user clicks the Stop button or leaves the Web page.
' Member identifier: &H00000402 (1026)
' ****************************************************************************************
Function HTMLDocumentEvents2_onstop (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onrowsdelete
' Fires when rows are about to be deleted from the recordset.
' Member identifier: &H80010020 (-2147418080)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onrowsdelete (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onrowsinserted
' Fires just after new rows are inserted in the current recordset.
' Member identifier: &H80010021 (-2147418079)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onrowsinserted (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: oncellchange
' Fires when data changes in the data provider.
' Member identifier: &H80010022 (-2147418078)
' ****************************************************************************************
Sub HTMLDocumentEvents2_oncellchange (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onpropertychange
' Fires when a property changes on the object.
' Member identifier: &H80010013 (-2147418093)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onpropertychange (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: ondatasetchanged
' Fires when the data set exposed by a data source object changes.
' Member identifier: &H8001000E (-2147418098)
' ****************************************************************************************
Sub HTMLDocumentEvents2_ondatasetchanged (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: ondataavailable
' Fires periodically as data arrives from data source objects that asynchronously transmit
' their data.
' Member identifier: &H8001000F (-2147418097)
' ****************************************************************************************
Sub HTMLDocumentEvents2_ondataavailable (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: ondatasetcomplete
' Fires to indicate that all data is available from the data source object.
' Member identifier: &H80010010 (-2147418096)
' ****************************************************************************************
Sub HTMLDocumentEvents2_ondatasetcomplete (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onbeforeeditfocus
' Fires before an object contained in an editable element enters a UI-activated state or
' when an editable container object is control selected.
' Member identifier: &H00000403 (1027)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onbeforeeditfocus (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onselectionchange
' Fires when the selection state of a document changes.
' Member identifier: &H0000040D (1037)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onselectionchange (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: oncontrolselect
' Fires when the user is about to make a control selection of the object.
' Member identifier: &H0000040C (1036)
' ****************************************************************************************
Function HTMLDocumentEvents2_oncontrolselect (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************

' ****************************************************************************************
' Function name: onmousewheel
' Fires when the wheel button is rotated.
' Member identifier: &H00000409 (1033)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onmousewheel (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onfocusin
' Fires for an element just prior to setting focus on that element.
' Member identifier: &H00000418 (1048)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onfocusin (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onfocusout
' Fires for the current element with focus immediately after moving focus to another element.
' Member identifier: &H00000419 (1049)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onfocusout (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onactivate
' Fires when the object is set as the active element.
' Member identifier: &H00000414 (1044)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onactivate (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: ondeactivate
' Fires when the IHTMLDocument2::activeElement is changed from the current object to
' another object in the parent document.
' Member identifier: &H00000415 (1045)
' ****************************************************************************************
Sub HTMLDocumentEvents2_ondeactivate (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onbeforeactivate
' Fires immediately before the object is set as the active element.
' Member identifier: &H00000417 (1047)
' ****************************************************************************************
Sub HTMLDocumentEvents2_onbeforeactivate (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams)

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

End Sub
' ****************************************************************************************

' ****************************************************************************************
' Function name: onbeforedeactivate
' Fires immediately before the IHTMLDocument2::activeElement is changed from the current
' object to another object in the parent document.
' Member identifier: &H0000040A (1034)
' ****************************************************************************************
Function HTMLDocumentEvents2_onbeforedeactivate (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByRef pdispparams As DispParams) As Long

'  Retrieve the IUnknown or IDispatch of the control that has fired the event.
   Local pthis As Dword : pthis = @@pCookie.pthis
'  Pointer to access the parameter
   Local pv As Variant Ptr : pv = pdispparams.VariantArgs
'  Pointer to an IHTMLEventObj interface for the current event.
   Local pEvtObj As Dword : pEvtObj = Variant#(@pv[0])

'  ===========================================================================================
'  *** Put your code here ***
'  ===========================================================================================

'  Return Value: If the event bubbles and is cancellable, return %TRUE to prevent the
'  event from bubbling to other event handlers in the document tree. Return %FALSE to
'  allow bubbling.
   Function = %FALSE

End Function
' ****************************************************************************************


' ****************************************************************************************
' HRESULT Invoke([in] I4 dispidMember, [in] *GUID riid, [in] UI4 lcid, [in] UI2 wFlags, [in] *DISPPARAMS pdispparams, [out] *VARIANT pvarResult, [out] *EXCEPINFO pexcepinfo, [out] *UINT puArgErr)
' ****************************************************************************************
Function HTMLDocumentEvents2_Invoke (ByVal pCookie As HTMLDocumentEvents2_IDispatchVtbl Ptr, ByVal dispidMember As Long, ByRef riid As Guid, _
   ByVal lcid As Dword, ByVal wFlags As Word, ByRef pdispparams As DispParams, ByRef pvarResult As Variant, _
   ByRef pexcepinfo As HTMLDocumentEvents2_EXCEPINFO, ByRef puArgErr As Dword) As Long

   Function = %FALSE

   If VarPtr(pdispparams) Then

      Select Case As Long dispidMember
         Case &H8001000A  ' (-2147418102)  ' // onhelp
            Function = HTMLDocumentEvents2_onhelp(pCookie, pdispparams)
         Case &HFFFFFDA8  ' (-600)  ' // onclick
            Function = HTMLDocumentEvents2_onclick(pCookie, pdispparams)
         Case &HFFFFFDA7  ' (-601)  ' // ondblclick
            Function = HTMLDocumentEvents2_ondblclick(pCookie, pdispparams)
         Case &HFFFFFDA6  ' (-602)  ' // onkeydown
            HTMLDocumentEvents2_onkeydown pCookie, pdispparams
         Case &HFFFFFDA4  ' (-604)  ' // onkeyup
            HTMLDocumentEvents2_onkeyup pCookie, pdispparams
         Case &HFFFFFDA5  ' (-603)  ' // onkeypress
            Function = HTMLDocumentEvents2_onkeypress(pCookie, pdispparams)
         Case &HFFFFFDA3  ' (-605)  ' // onmousedown
            HTMLDocumentEvents2_onmousedown pCookie, pdispparams
         Case &HFFFFFDA2  ' (-606)  ' // onmousemove
            HTMLDocumentEvents2_onmousemove pCookie, pdispparams
         Case &HFFFFFDA1  ' (-607)  ' // onmouseup
            HTMLDocumentEvents2_onmouseup pCookie, pdispparams
         Case &H80010009  ' (-2147418103)  ' // onmouseout
            HTMLDocumentEvents2_onmouseout pCookie, pdispparams
         Case &H80010008  ' (-2147418104)  ' // onmouseover
            HTMLDocumentEvents2_onmouseover pCookie, pdispparams
         Case &HFFFFFD9F  ' (-609)  ' // onreadystatechange
            HTMLDocumentEvents2_onreadystatechange pCookie, pdispparams
         Case &H80010004  ' (-2147418108)  ' // onbeforeupdate
            Function = HTMLDocumentEvents2_onbeforeupdate(pCookie, pdispparams)
         Case &H80010005  ' (-2147418107)  ' // onafterupdate
            HTMLDocumentEvents2_onafterupdate pCookie, pdispparams
         Case &H80010006  ' (-2147418106)  ' // onrowexit
            Function = HTMLDocumentEvents2_onrowexit(pCookie, pdispparams)
         Case &H80010007  ' (-2147418105)  ' // onrowenter
            HTMLDocumentEvents2_onrowenter pCookie, pdispparams
         Case &H8001000B  ' (-2147418101)  ' // ondragstart
            Function = HTMLDocumentEvents2_ondragstart(pCookie, pdispparams)
         Case &H8001000C  ' (-2147418100)  ' // onselectstart
            Function = HTMLDocumentEvents2_onselectstart(pCookie, pdispparams)
         Case &H8001000D  ' (-2147418099)  ' // onerrorupdate
            Function = HTMLDocumentEvents2_onerrorupdate(pCookie, pdispparams)
         Case &H000003FF  ' (1023)  ' // oncontextmenu
            Function = HTMLDocumentEvents2_oncontextmenu(pCookie, pdispparams)
         Case &H00000402  ' (1026)  ' // onstop
            Function = HTMLDocumentEvents2_onstop(pCookie, pdispparams)
         Case &H80010020  ' (-2147418080)  ' // onrowsdelete
            HTMLDocumentEvents2_onrowsdelete pCookie, pdispparams
         Case &H80010021  ' (-2147418079)  ' // onrowsinserted
            HTMLDocumentEvents2_onrowsinserted pCookie, pdispparams
         Case &H80010022  ' (-2147418078)  ' // oncellchange
            HTMLDocumentEvents2_oncellchange pCookie, pdispparams
         Case &H80010013  ' (-2147418093)  ' // onpropertychange
            HTMLDocumentEvents2_onpropertychange pCookie, pdispparams
         Case &H8001000E  ' (-2147418098)  ' // ondatasetchanged
            HTMLDocumentEvents2_ondatasetchanged pCookie, pdispparams
         Case &H8001000F  ' (-2147418097)  ' // ondataavailable
            HTMLDocumentEvents2_ondataavailable pCookie, pdispparams
         Case &H80010010  ' (-2147418096)  ' // ondatasetcomplete
            HTMLDocumentEvents2_ondatasetcomplete pCookie, pdispparams
         Case &H00000403  ' (1027)  ' // onbeforeeditfocus
            HTMLDocumentEvents2_onbeforeeditfocus pCookie, pdispparams
         Case &H0000040D  ' (1037)  ' // onselectionchange
            HTMLDocumentEvents2_onselectionchange pCookie, pdispparams
         Case &H0000040C  ' (1036)  ' // oncontrolselect
            Function = HTMLDocumentEvents2_oncontrolselect(pCookie, pdispparams)
         Case &H00000409  ' (1033)  ' // onmousewheel
            HTMLDocumentEvents2_onmousewheel pCookie, pdispparams
         Case &H00000418  ' (1048)  ' // onfocusin
            HTMLDocumentEvents2_onfocusin pCookie, pdispparams
         Case &H00000419  ' (1049)  ' // onfocusout
            HTMLDocumentEvents2_onfocusout pCookie, pdispparams
         Case &H00000414  ' (1044)  ' // onactivate
            HTMLDocumentEvents2_onactivate pCookie, pdispparams
         Case &H00000415  ' (1045)  ' // ondeactivate
            HTMLDocumentEvents2_ondeactivate pCookie, pdispparams
         Case &H00000417  ' (1047)  ' // onbeforeactivate
            HTMLDocumentEvents2_onbeforeactivate pCookie, pdispparams
         Case &H0000040A  ' (1034)  ' // onbeforedeactivate
            Function = HTMLDocumentEvents2_onbeforedeactivate(pCookie, pdispparams)

      End Select

   End If

End Function
' ****************************************************************************************
