
' ****************************************************************************************
' Interface name = IHTMLEventObj
' IID = {3050F32D-98B5-11CF-BB82-00AA00BDCE0B}
' Attributes = 4160 [&H1040] [Dual] [Dispatchable]
' Implied interface = IDispatch
' ****************************************************************************************

' ****************************************************************************************
' This interface provides access to the event processes, such as the element in which the
' event occurred, the state of the keyboard keys, the location of the mouse, and the state
' of the mouse buttons.
' The event object is only available during an event; that is, you can use it in event
' handlers but not in other code.
' Although all event properties are available to all event objects, some properties might
' not have meaningful values during some events. For example, the values retrieved by the
' IHTMLEventObj::fromElement and the IHTMLEventObj::toElement methods are meaningful only
' when processing the onmouseover and onmouseout events.
' ****************************************************************************************

' ****************************************************************************************
' [get_]srcElement property
' Retrieves the object that fired the event.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_srcElement (ByVal pthis As Dword Ptr, ByRef p As Dword) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_srcElement (ByVal pthis As Dword Ptr) As Dword
    Local p As Dword
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[7] Using Proto_IHTMLEventObj_get_srcElement(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]altKey property
' Retrieves a value that indicates the state of the ALT key.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_altKey (ByVal pthis As Dword Ptr, ByRef p As Integer) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_altKey (ByVal pthis As Dword Ptr) As Integer
    Local p As Integer
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[8] Using Proto_IHTMLEventObj_get_altKey(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]ctrlKey property
' Retrieves the state of the CTRL key.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_ctrlKey (ByVal pthis As Dword Ptr, ByRef p As Integer) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_ctrlKey (ByVal pthis As Dword Ptr) As Integer
    Local p As Integer
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[9] Using Proto_IHTMLEventObj_get_ctrlKey(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]shiftKey property
' Retrieves the state of the SHIFT key.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_shiftKey (ByVal pthis As Dword Ptr, ByRef p As Integer) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_shiftKey (ByVal pthis As Dword Ptr) As Integer
    Local p As Integer
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[10] Using Proto_IHTMLEventObj_get_shiftKey(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [put_]returnValue property
' Sets the return value from the event.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_put_returnValue (ByVal pthis As Dword Ptr, ByVal p As Variant) As Long
' ****************************************************************************************
Sub IHTMLEventObj_put_returnValue (ByVal pthis As Dword Ptr, ByVal p As Variant)
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Sub
    Call Dword @@pthis[11] Using Proto_IHTMLEventObj_put_returnValue(pthis, p) To HtmlResult
End Sub
' ****************************************************************************************

' ****************************************************************************************
' [get_]returnValue property
' Retrieves the return value from the event.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_returnValue (ByVal pthis As Dword Ptr, ByRef p As Variant) As Long
' ****************************************************************************************
Sub IHTMLEventObj_get_returnValue (ByVal pthis As Dword Ptr, ByRef p As Variant)
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Sub
    Call Dword @@pthis[12] Using Proto_IHTMLEventObj_get_returnValue(pthis, p) To HtmlResult
End Sub
' ****************************************************************************************

' ****************************************************************************************
' [put_]cancelBubble property
' Sets whether the current event should bubble up the hierarchy of event handlers.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_put_cancelBubble (ByVal pthis As Dword Ptr, ByVal p As Integer) As Long
' ****************************************************************************************
Sub IHTMLEventObj_put_cancelBubble (ByVal pthis As Dword Ptr, ByVal p As Integer)
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Sub
    Call Dword @@pthis[13] Using Proto_IHTMLEventObj_put_cancelBubble(pthis, p) To HtmlResult
End Sub
' ****************************************************************************************

' ****************************************************************************************
' [get_]cancelBubble property
' Retrieves whether the current event should bubble up the hierarchy of event handlers.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_cancelBubble (ByVal pthis As Dword Ptr, ByRef p As Integer) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_cancelBubble (ByVal pthis As Dword Ptr) As Integer
    Local p As Integer
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[14] Using Proto_IHTMLEventObj_get_cancelBubble(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]fromElement property
' Retrieves the object from which activation or the mouse pointer is exiting during the event.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_fromElement (ByVal pthis As Dword Ptr, ByRef p As Dword) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_fromElement (ByVal pthis As Dword Ptr) As Dword
    Local p As Dword
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[15] Using Proto_IHTMLEventObj_get_fromElement(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]toElement property
' Retrieves a reference to the object toward which the user is moving the mouse pointer.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_toElement (ByVal pthis As Dword Ptr, ByRef p As Dword) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_toElement (ByVal pthis As Dword Ptr) As Dword
    Local p As Dword
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[16] Using Proto_IHTMLEventObj_get_toElement(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [put_]keyCode property
' Sets the Unicode key code associated with the key that caused the event.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_put_keyCode (ByVal pthis As Dword Ptr, ByVal p As Long) As Long
' ****************************************************************************************
Sub IHTMLEventObj_put_keyCode (ByVal pthis As Dword Ptr, ByVal p As Long)
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Sub
    Call Dword @@pthis[17] Using Proto_IHTMLEventObj_put_keyCode(pthis, p) To HtmlResult
End Sub
' ****************************************************************************************

' ****************************************************************************************
' [get_]keyCode property
' Retrieves the Unicode key code associated with the key that caused the event.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_keyCode (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_keyCode (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[18] Using Proto_IHTMLEventObj_get_keyCode(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]button property
' Retrieves the mouse button pressed by the user.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_button (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_button (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[19] Using Proto_IHTMLEventObj_get_button(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]type property
' Sets or retrieves the event name from the event object.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_type (ByVal pthis As Dword Ptr, ByRef p As String) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_type (ByVal pthis As Dword Ptr) As String
    Local p As String
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[20] Using Proto_IHTMLEventObj_get_type(pthis, p) To HtmlResult
    Function = ACode$(p)
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]qualifier property
' Retrieves the name of the data member provided by a data source object.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_qualifier (ByVal pthis As Dword Ptr, ByRef p As String) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_qualifier (ByVal pthis As Dword Ptr) As String
    Local p As String
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[21] Using Proto_IHTMLEventObj_get_qualifier(pthis, p) To HtmlResult
    Function = ACode$(p)
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]reason property
' Retrieves the result of the data transfer for a data source object.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_reason (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_reason (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[22] Using Proto_IHTMLEventObj_get_reason(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]x property
' Retrieves the x-coordinate, in pixels, of the mouse pointer's position relative to a
' relatively positioned parent element.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_x (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_x (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[23] Using Proto_IHTMLEventObj_get_x(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]y property
' Retrieves the y-coordinate, in pixels, of the mouse pointer's position relative to a
' relatively positioned parent element.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_y (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_y (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[24] Using Proto_IHTMLEventObj_get_y(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]clientX property
' Retrieves the x-coordinate of the mouse pointer's position relative to the client area
' of the window, excluding window decorations and scroll bars.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_clientX (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_clientX (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[25] Using Proto_IHTMLEventObj_get_clientX(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]clientY property
' Retrieves the y-coordinate of the mouse pointer's position relative to the client area
' of the window, excluding window decorations and scroll bars.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_clientY (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_clientY (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[26] Using Proto_IHTMLEventObj_get_clientY(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]offsetX property
' Retrieves the x-coordinate of the mouse pointer's position relative to the object
' firing the event.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_offsetX (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_offsetX (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[27] Using Proto_IHTMLEventObj_get_offsetX(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]offsetY property
' Retrieves the y-coordinate of the mouse pointer's position relative to the object
' firing the event.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_offsetY (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_offsetY (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[28] Using Proto_IHTMLEventObj_get_offsetY(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]screenX property
' Retrieves the x-coordinate of the mouse pointer's position relative to the user's screen.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_screenX (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_screenX (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[29] Using Proto_IHTMLEventObj_get_screenX(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]screenY property
' Retrieves the y-coordinate of the mouse pointer's position relative to the user's screen.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_screenY (ByVal pthis As Dword Ptr, ByRef p As Long) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_screenY (ByVal pthis As Dword Ptr) As Long
    Local p As Long
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[30] Using Proto_IHTMLEventObj_get_screenY(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************

' ****************************************************************************************
' [get_]srcFilter property
' Retrieves the filter object that caused the onfilterchange event to fire.
' ****************************************************************************************
Declare Function Proto_IHTMLEventObj_get_srcFilter (ByVal pthis As Dword Ptr, ByRef p As Dword) As Long
' ****************************************************************************************
Function IHTMLEventObj_get_srcFilter (ByVal pthis As Dword Ptr) As Dword
    Local p As Dword
    If IsFalse pthis Then HtmlResult = %E_POINTER : Exit Function
    Call Dword @@pthis[31] Using Proto_IHTMLEventObj_get_srcFilter(pthis, p) To HtmlResult
    Function = p
End Function
' ****************************************************************************************
